OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Curtha le ceanáin",
    "Removed from favorites" : "Bainte de cheanáin",
    "You added {file} to your favorites" : "Chuir tú {file} le do cheanáin",
    "You removed {file} from your favorites" : "Bhain tú {file} de do cheanáin",
    "Favorites" : "Ceanáin",
    "File changes" : "Athruithe comhaid",
    "Created by {user}" : "Cruthaithe ag {user}",
    "Changed by {user}" : "Athraithe ag {user}",
    "Deleted by {user}" : "Scriosta ag {user}",
    "Restored by {user}" : "Athchóiríodh ag {user}",
    "Renamed by {user}" : "Athainmnithe ag {user}",
    "Moved by {user}" : "Ar athraíodh a ionad ag {user}",
    "\"remote account\"" : "\"cuntas cianda\"",
    "You created {file}" : "Chruthaigh tú {file}",
    "You created an encrypted file in {file}" : "Chruthaigh tú comhad criptithe i {file}",
    "{user} created {file}" : "{user} cruthaithe {file}",
    "{user} created an encrypted file in {file}" : "{user} chruthaigh sé comhad criptithe i {file}",
    "{file} was created in a public folder" : "Cruthaíodh {file} i bhfillteán poiblí",
    "You changed {file}" : "D'athraigh tú {file}",
    "You changed an encrypted file in {file}" : "D'athraigh tú comhad criptithe i {file}",
    "{user} changed {file}" : "D'athraigh {user} {file}",
    "{user} changed an encrypted file in {file}" : "D'athraigh {user} comhad criptithe i {file}",
    "You deleted {file}" : "Scrios tú {file}",
    "You deleted an encrypted file in {file}" : "Scrios tú comhad criptithe i {file}",
    "{user} deleted {file}" : "Scriosadh {user} {file}",
    "{user} deleted an encrypted file in {file}" : "Scrios {user} comhad criptithe i {file}",
    "You restored {file}" : "D'aischuir tú {file}",
    "{user} restored {file}" : "D'aischuir {user} {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "D'athainmnigh tú {oldfile} (i bhfolach) go {newfile} (i bhfolach)",
    "You renamed {oldfile} (hidden) to {newfile}" : "D'athainmnigh tú {oldfile} (i bhfolach) go {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "D'athainmnigh tú {oldfile} go {newfile} (i bhfolach)",
    "You renamed {oldfile} to {newfile}" : "D'athainmnigh tú {oldfile} go {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} athainmnithe {oldfile} (i bhfolach) go {newfile} (i bhfolach)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} athainmnithe {oldfile} (i bhfolach) go {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} athainmnithe {oldfile} go {newfile} (i bhfolach)",
    "{user} renamed {oldfile} to {newfile}" : "Athainmníodh {user} {oldfile} go {newfile}",
    "You moved {oldfile} to {newfile}" : "Bhog tú {oldfile} go {newfile}",
    "{user} moved {oldfile} to {newfile}" : "Bhog {user} {oldfile} go {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Cuireadh comhad le do<strong>favorites</strong>nó baineadh de",
    "Files" : "Comhaid",
    "A file or folder has been <strong>changed</strong>" : "<strong>Athraíodh</strong>comhad nó fillteán",
    "A favorite file or folder has been <strong>changed</strong>" : "<strong>Athraíodh</strong>comhad nó fillteán is fearr leat",
    "Failed to authorize" : "Theip ar údarú",
    "Invalid folder path" : "Conair fillteáin neamhbhailí",
    "Folder not found" : "Fillteán gan aimsiú",
    "The file cannot be found" : "Ní féidir an comhad a aimsiú",
    "The destination path does not exist: %1$s" : "Níl an cosán sprice ann:%1$s",
    "You do not have permission to create a file at the specified location" : "Níl cead agat comhad a chruthú ag an suíomh sonraithe",
    "The file could not be converted." : "Níorbh fhéidir an comhad a thiontú.",
    "Could not get relative path to converted file" : "Níorbh fhéidir cosán coibhneasta a fháil chuig an gcomhad tiontaithe",
    "Favorite files" : "Comhaid is fearr leat",
    "No favorites" : "Gan aon cheanáin",
    "More favorites" : "Gan aon cheanáin",
    "Accept" : "Glac",
    "Reject" : "Diúltaigh",
    "Incoming ownership transfer from {user}" : "Aistriú úinéireachta isteach ó {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Ar mhaith leat glacadh le {path}?\n\nNóta: Féadfaidh an próiseas aistrithe tar éis glacadh suas le 1 uair an chloig a ghlacadh.",
    "Ownership transfer denied" : "Aistriú úinéireachta diúltaithe",
    "Your ownership transfer of {path} was denied by {user}." : "Dhiúltaigh {user} d'aistriú úinéireachta ar {path}.",
    "Ownership transfer failed" : "Theip ar aistriú úinéireachta",
    "Your ownership transfer of {path} to {user} failed." : "Theip ar d'aistriú úinéireachta de {path} go {user}.",
    "The ownership transfer of {path} from {user} failed." : "Theip ar aistriú úinéireachta {path} ó {user}.",
    "Ownership transfer done" : "Aistriú úinéireachta déanta",
    "Your ownership transfer of {path} to {user} has completed." : "Tá d'aistriú úinéireachta de {path} go {user} críochnaithe.",
    "The ownership transfer of {path} from {user} has completed." : "Tá aistriú úinéireachta {path} ó {user} críochnaithe.",
    "in %s" : "i %s",
    "Transferred from %1$s on %2$s" : "Aistrithe ó %1$s ar %2$s",
    "Files compatibility" : "Comhoiriúnacht comhaid",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Ceadaigh comhaid a shrianadh lena chinntiú gur féidir comhaid a shioncronú le gach cliant. De réir réamhshocraithe ceadaítear gach comhadainm atá bailí ar POSIX (m.sh. Linux nó macOS).",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Tar éis na hainmneacha comhad atá comhoiriúnach le Windows a chumasú, ní féidir comhaid atá ann cheana a mhodhnú a thuilleadh ach is féidir lena n-úinéir iad a athainmniú go hainmneacha nua bailí.",
    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Is féidir comhaid a aistriú go huathoibríoch freisin tar éis an socrú seo a chumasú, féach ar an doiciméadú faoin ordú occ.",
    "Enforce Windows compatibility" : "Comhoiriúnacht Windows a fhorfheidhmiú",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Cuirfidh sé seo bac ar ainmneacha comhaid nach bhfuil bailí ar chórais Windows, ar nós ainmneacha forchoimeádta nó carachtair speisialta a úsáid. Ach ní chuirfidh sé seo i bhfeidhm comhoiriúnacht íogaireacht cáis.",
    "File Management" : "Bainistíocht Comhad",
    "Home" : "Baile",
    "Target folder does not exist any more" : "Níl an spriocfhillteán ann a thuilleadh",
    "Reload current directory" : "Athlódáil an eolaire reatha",
    "Go to the \"{dir}\" directory" : "Téigh go dtí an eolaire \"{dir}\".",
    "Current directory path" : "An cosán eolaire reatha",
    "Your have used your space quota and cannot upload files anymore" : "D'úsáid tú do chuóta spáis agus ní féidir leat comhaid a uaslódáil a thuilleadh",
    "You do not have permission to upload or create files here." : "Níl cead agat comhaid a uaslódáil nó a chruthú anseo.",
    "Drag and drop files here to upload" : "Tarraing agus scaoil comhaid anseo le huaslódáil",
    "Favorite" : "is fearr leat",
    "Back" : "Ar ais",
    "Toggle selection for file \"{displayName}\"" : "Scoránaigh an roghnúchán don chomhad \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Scoránaigh an roghnúchán don fhillteán \"{displayName}\"",
    "File is loading" : "Comhad á luchtú",
    "Folder is loading" : "Tá an fillteán á luchtú",
    "Filename" : "Ainm comhaid",
    "Folder name" : "Ainm fillteáin",
    "This node is unavailable" : "Níl an nód seo ar fáil",
    "Another entry with the same name already exists." : "Tá iontráil eile leis an ainm céanna ann cheana féin.",
    "Invalid filename." : "Ainm comhaid neamhbhailí.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Athainmnithe \"{oldName}\" go \"{newName}\"",
    "Rename file" : "Athainmnigh an comhad",
    "Folder" : "Fillteán",
    "Unknown file type" : "Cineál comhaid anaithnid",
    "{ext} image" : "íomhá {ext}",
    "{ext} video" : "físeán {ext}",
    "{ext} audio" : "fuaim {ext}",
    "{ext} text" : "téacs {ext}",
    "Pending" : "Ar feitheamh",
    "Unknown date" : "Dáta anaithnid",
    "Clear filter" : "Glan an scagaire",
    "Modified" : "Athraithe",
    "Search everywhere" : "Cuardaigh i ngach áit",
    "Type" : "Cineál",
    "Active filters" : "Scagairí gníomhacha",
    "Remove filter" : "Bain an scagaire",
    "Total rows summary" : "Achoimre ar na sraitheanna iomlána",
    "Toggle selection for all files and folders" : "Scoránaigh an roghnúchán do gach comhad agus fillteán",
    "Name" : "Ainm",
    "File type" : "Cineál comhaid",
    "Size" : "Méid",
    "\"{displayName}\" failed on some elements" : "\"{displayName}\" theip ar roinnt gnéithe",
    "\"{displayName}\" batch action executed successfully" : "D'éirigh le beart baisce \"{displayName}\" a rith",
    "\"{displayName}\" action failed" : "Theip ar an ngníomh \"{displayName}\".",
    "Actions" : "Gníomhartha",
    "(selected)" : "(roghnaithe)",
    "List of files and folders." : "Liosta de chomhaid agus fillteáin.",
    "You have used your space quota and cannot upload files anymore." : "D'úsáid tú do chuóta spáis agus ní féidir leat comhaid a uaslódáil a thuilleadh.",
    "Column headers with buttons are sortable." : "Is féidir ceanntásca colún le cnaipí a shórtáil.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Níl an liosta seo le fáil go hiomlán ar chúiseanna feidhmíochta. Déanfar na comhaid a rindreáil agus tú ag dul tríd an liosta.",
    "File not found" : "Comhad gan aimsiú",
    "_{count} selected_::_{count} selected_" : ["{count} roghnaithe","{count} roghnaithe","{count} roghnaithe","{count} roghnaithe","{count} roghnaithe"],
    "Search globally by filename …" : "Cuardaigh go domhanda de réir ainm comhaid …",
    "Search here by filename …" : "Cuardaigh anseo de réir ainm comhaid …",
    "Search scope options" : "Roghanna raon feidhme cuardaigh",
    "Search globally" : "Cuardaigh go domhanda",
    "{usedQuotaByte} used" : "{usedQuotaByte} úsáidte",
    "{used} of {quota} used" : "{used} de {quota} in úsáid",
    "{relative}% used" : "{relative}% in úsáid",
    "Could not refresh storage stats" : "Níorbh fhéidir na staitisticí stórála a athnuachan",
    "Your storage is full, files can not be updated or synced anymore!" : "Tá do stóras lán, ní féidir comhaid a nuashonrú ná a shioncronú a thuilleadh!",
    "Storage information" : "Faisnéis stórála",
    "Storage quota" : "Cuóta stórála",
    "New folder" : "Fillteán nua",
    "Create new folder" : "Cruthaigh fillteán nua",
    "This name is already in use." : "Tá an t-ainm seo in úsáid cheana féin.",
    "Create" : "Cruthaigh",
    "Fill template fields" : "Líon réimsí teimpléid",
    "Submitting fields …" : "Réimsí á gcur isteach…",
    "Submit" : "Cuir isteach",
    "Choose a file or folder to transfer" : "Roghnaigh comhad nó fillteán le haistriú",
    "Transfer" : "Aistriú",
    "Transfer {path} to {userid}" : "Aistrigh {path} go {userid}",
    "Invalid path selected" : "Conair neamhbhailí roghnaithe",
    "Unknown error" : "Earráid anaithnid",
    "Ownership transfer request sent" : "Iarratas aistrithe úinéireachta seolta",
    "Cannot transfer ownership of a file or folder you do not own" : "Ní féidir úinéireacht comhaid nó fillteáin nach leat a aistriú",
    "Transfer ownership of a file or folder" : "Aistrigh úinéireacht comhaid nó fillteáin",
    "Choose file or folder to transfer" : "Roghnaigh comhad nó fillteán le haistriú",
    "Change" : "Athrú",
    "New owner" : "Úinéir nua",
    "Keep {old}" : "Coinnigh {old}",
    "Keep without extension" : "Coinnigh gan síneadh",
    "Use {new}" : "Úsáid {new}",
    "Remove extension" : "Bain breiseán",
    "Change file extension" : "Athraigh síneadh comhad",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Má athraítear iarmhír an chomhaid ó \"{old}\" go \"{new}\" seans go mbeidh an comhad do-léite.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Má bhaintear an iarmhír chomhaid \"{old}\" seans go mbeidh an comhad do-léite.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Má chuirtear an síneadh comhad \"{new}\" leis, seans go mbeidh an comhad do-léite.",
    "Do not show this dialog again." : "Ná taispeáin an dialóg seo arís.",
    "Select file or folder to link to" : "Roghnaigh comhad nó fillteán le nascadh leis",
    "Choose {file}" : "Roghnaigh {file}",
    "Share" : "Comhroinn",
    "Shared by link" : "Roinnte ag nasc",
    "Shared" : "Roinnte",
    "Switch to list view" : "Athraigh go dtí an amharc liosta",
    "Switch to grid view" : "Téigh go dtí an radharc greille",
    "The file could not be found" : "Níorbh fhéidir an comhad a aimsiú",
    "Upload was cancelled by user" : "Chuir an t-úsáideoir an uaslódáil ar ceal",
    "Not enough free space" : "Níl go leor spás saor in aisce",
    "Operation is blocked by access control" : "Cuireann rialú rochtana bac ar an oibríocht",
    "Error during upload: {message}" : "Earráid le linn uaslódála: {message}",
    "Error during upload, status code {status}" : "Earráid le linn uaslódála, cód stádais {status}",
    "Unknown error during upload" : "Earráid anaithnid le linn uaslódála",
    "\"{displayName}\" action executed successfully" : "Cuireadh an gníomh \"{displayName}\" i gcrích go rathúil",
    "Loading current folder" : "An fillteán reatha á lódáil",
    "Retry" : "Bain triail eile as",
    "No files in here" : "Níl aon chomhaid istigh anseo",
    "Upload some content or sync with your devices!" : "Uaslódáil roinnt inneachair nó sioncronaigh le do ghléasanna!",
    "Go back" : "Dul ar ais",
    "Views" : "Radhairc",
    "Files settings" : "Socruithe comhaid",
    "Your files" : "Do chuid comhad",
    "Open in files" : "Oscail i gcomhaid",
    "File cannot be accessed" : "Ní féidir an comhad a rochtain",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Níorbh fhéidir an comhad a aimsiú nó níl cead agat féachaint air. Iarr ar an seoltóir é a roinnt.",
    "No search results for “{query}”" : "Gan aon torthaí cuardaigh le haghaidh ”{query}”",
    "Search for files" : "Cuardaigh comhaid",
    "Clipboard is not available" : "Níl fáil ar an ngearrthaisce",
    "WebDAV URL copied to clipboard" : "URL WebDAV cóipeáilte chuig an ngearrthaisce",
    "Default view" : "Amharc réamhshocraithe",
    "All files" : "Gach comhad",
    "Personal files" : "Comhaid phearsanta",
    "Sort favorites first" : "Sórtáil na cinn is ansa leat ar dtús",
    "Sort folders before files" : "Sórtáil fillteáin roimh chomhaid",
    "Show hidden files" : "Taispeáin comhaid i bhfolach",
    "Show file type column" : "Taispeáin colún cineál comhaid",
    "Crop image previews" : "Réamhamhairc íomhá barr",
    "Enable folder tree" : "Cumasaigh crann fillteáin",
    "Additional settings" : "Socruithe breise",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "URL WebDAV",
    "Copy to clipboard" : "Cóipeáil chuig an ngearrthaisce",
    "Use this address to access your Files via WebDAV" : "Úsáid an seoladh seo chun do Chomhaid a rochtain trí WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Má tá 2FA cumasaithe agat, ní mór duit pasfhocal aip nua a chruthú agus a úsáid trí chliceáil anseo.",
    "Warnings" : "Rabhaidh",
    "Prevent warning dialogs from open or reenable them." : "Cosc a chur ar dialóga rabhaidh ó iad a oscailt nó iad a athchumasú.",
    "Show a warning dialog when changing a file extension." : "Taispeáin dialóg rabhaidh nuair a athraítear síneadh comhad.",
    "Keyboard shortcuts" : "Aicearraí méarchláir",
    "Speed up your Files experience with these quick shortcuts." : "Déan do thaithí Comhaid a bhrostú leis na haicearraí tapa seo.",
    "Open the actions menu for a file" : "Oscail an roghchlár gníomhartha le haghaidh comhad",
    "Rename a file" : "Athainmnigh comhad",
    "Delete a file" : "Scrios comhad",
    "Favorite or remove a file from favorites" : "Is ansa leat nó bain comhad ó cheanáin",
    "Manage tags for a file" : "Bainistigh clibeanna le haghaidh comhaid",
    "Selection" : "Roghnú",
    "Select all files" : "Roghnaigh gach comhad",
    "Deselect all files" : "Díroghnaigh gach comhad",
    "Select or deselect a file" : "Roghnaigh nó díroghnaigh comhad",
    "Select a range of files" : "Roghnaigh raon comhad",
    "Navigation" : "Loingseoireacht",
    "Navigate to the parent folder" : "Déan nascleanúint go dtí an fillteán tuismitheora",
    "Navigate to the file above" : "Déan nascleanúint go dtí an comhad thuas",
    "Navigate to the file below" : "Déan nascleanúint go dtí an comhad thíos",
    "Navigate to the file on the left (in grid mode)" : "Déan nascleanúint go dtí an comhad ar chlé (i mód greille)",
    "Navigate to the file on the right (in grid mode)" : "Déan nascleanúint go dtí an comhad ar dheis (i mód greille)",
    "View" : "Amharc",
    "Toggle the grid view" : "Scoránaigh an radharc greille",
    "Open the sidebar for a file" : "Oscail an barra taoibh le haghaidh comhad",
    "Show those shortcuts" : "Taispeáin na haicearraí sin",
    "You" : "tú",
    "Shared multiple times with different people" : "Roinnte go minic le daoine éagsúla",
    "Unable to change the favorite state of the file" : "Ní féidir staid an chomhaid is fearr leat a athrú",
    "Error while loading the file data" : "Earráid agus sonraí an chomhaid á lódáil",
    "Owner" : "Úinéir",
    "Remove from favorites" : "Bain ó cheanáin",
    "Add to favorites" : "Cuir le ceanáin",
    "Tags" : "Clibeanna",
    "Blank" : "Bán",
    "Unable to create new file from template" : "Ní féidir comhad nua a chruthú ón teimpléad",
    "Pick a template for {name}" : "Roghnaigh teimpléad le haghaidh {name}",
    "Create a new file with the selected template" : "Cruthaigh comhad nua leis an teimpléad roghnaithe",
    "Creating file" : "Comhad a chruthú",
    "Save as {displayName}" : "Sábháil mar {displayName}",
    "Save as …" : "Sábháil mar…",
    "Converting files …" : "Comhaid á thiontú…",
    "Failed to convert files: {message}" : "Theip ar thiontú comhaid: {message}",
    "All files failed to be converted" : "Theip ar gach comhad a thiontú",
    "One file could not be converted: {message}" : "Níorbh fhéidir comhad amháin a thiontú:{message}",
    "_One file could not be converted_::_%n files could not be converted_" : ["Níorbh fhéidir comhad amháin a thiontú","Níorbh fhéidir %n comhad a thiontú","Níorbh fhéidir %n comhad a thiontú","Níorbh fhéidir %n comhad a thiontú","Níorbh fhéidir %n comhad a thiontú"],
    "_One file successfully converted_::_%n files successfully converted_" : ["D'éirigh le comhad amháin a thiontú","D'éirigh le %n comhad a thiontú","D'éirigh le %n comhad a thiontú","D'éirigh le %n comhad a thiontú","D'éirigh le %n comhad a thiontú"],
    "Files successfully converted" : "Comhaid a thiontú go rathúil",
    "Failed to convert files" : "Theip ar thiontú comhaid",
    "Converting file …" : "Comhad á thiontú…",
    "File successfully converted" : "D'éirigh leis an gcomhad a thiontú",
    "Failed to convert file: {message}" : "Theip ar an gcomhad a thiontú: {message}",
    "Failed to convert file" : "Theip ar thiontú an chomhaid",
    "Deletion cancelled" : "Scriosadh cealaithe",
    "Leave this share" : "Fág an sciar seo",
    "Leave these shares" : "Fág na scaireanna seo",
    "Disconnect storage" : "Déan stóráil a dhícheangal",
    "Disconnect storages" : "Déan stórais a dhícheangal",
    "Delete permanently" : "Scrios go buan",
    "Delete and unshare" : "Scrios agus díroinnte",
    "Delete file" : "Scrios an comhad",
    "Delete files" : "Scrios comhaid",
    "Delete folder" : "Scrios fillteán",
    "Delete folders" : "Scrios fillteáin",
    "Delete" : "Scrios",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Tá tú ar tí {count} mír a scriosadh go buan","Tá tú ar tí {count} mír a scriosadh go buan","Tá tú ar tí {count} mír a scriosadh go buan","Tá tú ar tí {count} mír a scriosadh go buan","Tá tú ar tí {count} mír a scriosadh go buan"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Tá tú ar tí {count} mír a scriosadh","Tá tú ar tí {count} mír a scriosadh","Tá tú ar tí {count} mír a scriosadh","Tá tú ar tí {count} mír a scriosadh","Tá tú ar tí {count} mír a scriosadh"],
    "Confirm deletion" : "Deimhnigh scriosadh",
    "Cancel" : "Cealaigh",
    "Download" : "Íoslódáil",
    "Moving \"{source}\" to \"{destination}\" …" : "Ag bogadh \"{source}\" go \"{destination}\" ...",
    "Copying \"{source}\" to \"{destination}\" …" : "“{source}” á chóipeáil go “{destination}”…",
    "Destination is not a folder" : "Ní fillteán é ceann scríbe",
    "This file/folder is already in that directory" : "Tá an comhad/fillteán seo san eolaire sin cheana féin",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Ní féidir leat comhad/fillteán a bhogadh isteach ann féin nó isteach i bhfofhillteán de féin",
    "(copy)" : "(cóip)",
    "(copy %n)" : "(cóip %n)",
    "Move cancelled" : "Bogadh ar ceal",
    "A file or folder with that name already exists in this folder" : "Tá comhad nó fillteán leis an ainm sin san fhillteán seo cheana",
    "The files are locked" : "Tá na comhaid faoi ghlas",
    "The file does not exist anymore" : "Níl an comhad ann a thuilleadh",
    "Choose destination" : "Roghnaigh ceann scríbe",
    "Copy to {target}" : "Cóipeáil chuig {target}",
    "Copy" : "Cóipeáil",
    "Move to {target}" : "Bog go {target}",
    "Move" : "Bog",
    "Move or copy operation failed" : "Theip ar an oibríocht a bhogadh nó a chóipeáil",
    "Move or copy" : "Bog nó cóipeáil",
    "Cancelled move or copy of \"{filename}\"." : "Cealaíodh bogadh nó cóip de \"{filename}\".",
    "Cancelled move or copy operation" : "Oibríocht aistrithe nó cóipeála curtha ar ceal",
    "Open folder {displayName}" : "Oscail fillteán {displayName}",
    "Open in Files" : "Oscail i Comhaid",
    "Open locally" : "Oscail go háitiúil",
    "Failed to redirect to client" : "Theip ar atreorú chuig an gcliant",
    "Open file locally" : "Oscail comhad go háitiúil",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Ba cheart an comhad a oscailt anois ar do ghléas. Mura ndéanann sé, seiceáil le do thoil go bhfuil an aip deisce suiteáilte agat.",
    "Retry and close" : "Bain triail eile as agus dún",
    "Open online" : "Oscail ar líne",
    "Rename" : "Athainmnigh",
    "Open details" : "Sonraí oscailte",
    "View in folder" : "Amharc san fhillteán",
    "Today" : "Inniu",
    "Last 7 days" : "7 lá seo caite",
    "Last 30 days" : "30 lá anuas",
    "This year ({year})" : "i mbliana ({year})",
    "Last year ({year})" : "An bhliain seo caite {year}",
    "Documents" : "Doiciméid",
    "Spreadsheets" : "Scarbhileoga",
    "Presentations" : "Cur i láthair",
    "PDFs" : "PDFs",
    "Folders" : "Fillteáin",
    "Audio" : "Fuaime",
    "Photos and images" : "Grianghraif agus íomhánna",
    "Videos" : "Físeáin",
    "New folder creation cancelled" : "Cruthú fillteán nua curtha ar ceal",
    "Created new folder \"{name}\"" : "Cruthaíodh fillteán nua \"{name}\"",
    "Unable to initialize the templates directory" : "Ní féidir eolaire na dteimpléad a thúsú",
    "Create templates folder" : "Cruthaigh fillteán teimpléid",
    "Templates" : "Teimpléid",
    "New template folder" : "Fillteán teimpléid nua",
    "In folder" : "I bhfillteán",
    "Search in folder: {folder}" : "Cuardaigh i bhfillteán: {folder}",
    "One of the dropped files could not be processed" : "Níorbh fhéidir ceann de na comhaid a thit a phróiseáil",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Ní thacaíonn do bhrabhsálaí leis an API System File. Ní dhéanfar eolaire a uaslódáil",
    "No files to upload" : "Gan comhaid a uaslódáil",
    "Unable to create the directory {directory}" : "Ní féidir an t-eolaire {directory} a chruthú",
    "Some files could not be uploaded" : "Níorbh fhéidir roinnt comhad a uaslódáil",
    "Files uploaded successfully" : "D'éirigh le huaslódáil comhaid",
    "No files to process" : "Níl aon chomhaid le próiseáil",
    "Some files could not be copied" : "Níorbh fhéidir roinnt comhad a chóipeáil",
    "Some files could not be moved" : "Níorbh fhéidir roinnt comhad a bhogadh",
    "Files copied successfully" : "D'éirigh le cóipeáil na gcomhaid",
    "Files moved successfully" : "Bogadh na comhaid go rathúil",
    "Conflicts resolution skipped" : "Léiríodh réiteach coinbhleachta",
    "Upload cancelled" : "Cuireadh an t-uaslódáil ar ceal",
    "Could not rename \"{oldName}\", it does not exist any more" : "Níorbh fhéidir \"{oldName}\" a athainmniú, níl sé ann a thuilleadh",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Tá an t-ainm \"{newName}\" in úsáid cheana féin san fhillteán \"{dir}\". Roghnaigh ainm eile le do thoil.",
    "Could not rename \"{oldName}\"" : "Níorbh fhéidir \"{oldName}\" a athainmniú",
    "This operation is forbidden" : "Tá an oibríocht seo toirmiscthe",
    "This directory is unavailable, please check the logs or contact the administrator" : "Níl an t-eolaire seo ar fáil, seiceáil na logaí nó déan teagmháil leis an riarthóir le do thoil",
    "Storage is temporarily not available" : "Níl stóráil ar fáil go sealadach",
    "Unexpected error: {error}" : "Earráid gan choinne: {error}",
    "_%n file_::_%n files_" : ["%n comhad","%n comhaid","%n comhaid","%n comhaid","%n comhaid"],
    "_%n folder_::_%n folders_" : ["%n fillteán","%n fillteáin","%n fillteáin","%n fillteáin","%n fillteáin"],
    "_%n hidden_::_%n hidden_" : ["%n i bhfolach","%n i bhfolach","%n i bhfolach","%n i bhfolach","%n i bhfolach"],
    "Filename must not be empty." : "Ní ceadmhach ainm an chomhaid a bheith folamh.",
    "\"{char}\" is not allowed inside a filename." : "Ní cheadaítear \"{char}\" taobh istigh d'ainm comhaid.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "Is ainm forchoimeádta é \"{segment}\" agus ní cheadaítear é d'ainmneacha comhaid.",
    "\"{extension}\" is not an allowed filetype." : "Ní cineál comhaid ceadaithe é \"{extension}\".",
    "Filenames must not end with \"{extension}\"." : "Níor cheart go gcríochnaíonn comhaid chomhad le \"{extension}\".",
    "List of favorite files and folders." : "Liosta de na comhaid agus na fillteáin is fearr leat.",
    "No favorites yet" : "Níl aon cheanáin go fóill",
    "Files and folders you mark as favorite will show up here" : "Taispeánfar comhaid agus fillteáin a mharcálann tú mar is fearr leat anseo",
    "List of your files and folders." : "Liosta de do chuid comhad agus fillteáin.",
    "All folders" : "Gach fillteáin",
    "List of your files and folders that are not shared." : "Liosta de do chuid comhad agus fillteáin nach bhfuil roinnte.",
    "No personal files found" : "Níor aimsíodh aon chomhaid phearsanta",
    "Files that are not shared will show up here." : "Taispeánfar comhaid nach bhfuil roinnte anseo.",
    "Recent" : "le déanaí",
    "List of recently modified files and folders." : "Liosta de chomhaid agus de fhillteáin a athraíodh le déanaí.",
    "No recently modified files" : "Níl aon chomhaid athraithe le déanaí",
    "Files and folders you recently modified will show up here." : "Taispeánfar comhaid agus fillteáin a d'athraigh tú le déanaí anseo.",
    "Search" : "Cuardach",
    "Search results within your files." : "Torthaí cuardaigh laistigh de do chuid comhad.",
    "No entries found in this folder" : "Níor aimsíodh aon iontrálacha san fhillteán seo",
    "Select all" : "Roghnú go léir",
    "Upload too large" : "Íoslódáil ró-mhór",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Sáraíonn na comhaid atá tú ag iarraidh a uaslódáil an t-uasmhéid le haghaidh uaslódáil comhad ar an bhfreastalaí seo.",
    "File could not be found" : "Níorbh fhéidir an comhad a aimsiú",
    "Show list view" : "Taispeáin amharc liosta",
    "Show grid view" : "Taispeáin radharc greille",
    "Close" : "Dún",
    "Could not create folder \"{dir}\"" : "Níorbh fhéidir fillteán \"{dir}\" a chruthú",
    "This will stop your current uploads." : "Cuirfidh sé seo stop le d'uaslódálacha reatha.",
    "Upload cancelled." : "Cuireadh an t-uaslódáil ar ceal.",
    "Processing files …" : "Comhaid á bpróiseáil…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ní féidir {filename} a uaslódáil mar gur eolaire é nó go bhfuil 0 beart ann",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Níl go leor spáis saor in aisce, tá {size1} á uaslódáil agat ach níl ach {size2} fágtha",
    "Target folder \"{dir}\" does not exist any more" : "Níl an spriocfhillteán \"{dir}\" ann a thuilleadh",
    "An unknown error has occurred" : "Tharla earráid anaithnid",
    "File could not be uploaded" : "Níorbh fhéidir an comhad a uaslódáil",
    "Uploading …" : "Á uaslódáil…",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "Á uaslódáil … ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} di {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Ní thacaítear le huaslódáil an mhír sin",
    "Error when assembling chunks, status code {status}" : "Earráid agus smután á chur le chéile, cód stádais {status}",
    "Choose target folder" : "Roghnaigh fillteán sprice",
    "Set reminder" : "Socraigh meabhrúchán",
    "Edit locally" : "Cuir in eagar go háitiúil",
    "Open" : "Oscail",
    "Could not load info for file \"{file}\"" : "Níorbh fhéidir faisnéis don chomhad \"{file}\" a lódáil",
    "Details" : "Sonraí",
    "Please select tag(s) to add to the selection" : "Roghnaigh clib(í) le cur leis an rogha le do thoil",
    "Apply tag(s) to selection" : "Cuir clib(í) i bhfeidhm ar an roghnúchán",
    "Select directory \"{dirName}\"" : "Roghnaigh eolaire \"{dirName}\"",
    "Select file \"{fileName}\"" : "Roghnaigh comhad \"{fileName}\"",
    "Unable to determine date" : "Ní féidir an dáta a chinneadh",
    "Could not move \"{file}\", target exists" : "Níorbh fhéidir \"{file}\" a bhogadh, tá an sprioc ann",
    "Could not move \"{file}\"" : "Níorbh fhéidir \"{file}\" a bhogadh",
    "copy" : "cóip",
    "Could not copy \"{file}\", target exists" : "Níorbh fhéidir \"{file}\" a chóipeáil, tá an sprioc ann",
    "Could not copy \"{file}\"" : "Níorbh fhéidir \"{file}\" a chóipeáil",
    "Copied {origin} inside {destination}" : "Cóipeáladh {origin} taobh istigh de {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Cóipeáladh {origin} agus {nbfiles} comhaid eile laistigh de {destination}",
    "{newName} already exists" : "Tá {newName} ann cheana",
    "Could not create file \"{file}\"" : "Níorbh fhéidir comhad \"{file}\" a chruthú",
    "Could not create file \"{file}\" because it already exists" : "Níorbh fhéidir an comhad \"{file}\" a chruthú toisc go bhfuil sé ann cheana",
    "Could not create folder \"{dir}\" because it already exists" : "Níorbh fhéidir fillteán \"{dir}\" a chruthú toisc go bhfuil sé ann cheana",
    "Could not fetch file details \"{file}\"" : "Níorbh fhéidir sonraí an chomhaid \"{file}\" a fháil",
    "Error deleting file \"{fileName}\"." : "Earráid agus comhad \"{fileName}\" á scriosadh.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Níl aon toradh cuardaigh i bhfillteáin eile le haghaidh {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Cuir isteach níos mó ná dhá charachtar chun cuardach a dhéanamh i bhfillteáin eile",
    "{dirs} and {files}" : "{dirs} agus {files}",
    "_including %n hidden_::_including %n hidden_" : ["lena n-áirítear %n i bhfolach","lena n-áirítear %n i bhfolach","lena n-áirítear %n i bhfolach","lena n-áirítear %n i bhfolach","lena n-áirítear %n i bhfolach"],
    "You do not have permission to upload or create files here" : "Níl cead agat comhaid a uaslódáil nó a chruthú anseo",
    "_Uploading %n file_::_Uploading %n files_" : ["%n comhad á uaslódáil","%n comhaid á uaslódáil","%n comhaid á uaslódáil","%n comhaid á uaslódáil","%n comhaid á uaslódáil"],
    "New" : "Nua",
    "New file/folder menu" : "New file/folder menu",
    "Select file range" : "Roghnaigh raon comhaid",
    "{used}%" : "{used}%",
    "{used} used" : "{used} in úsáid",
    "\"{name}\" is an invalid file name." : "Is ainm comhaid neamhbhailí é \"{name}\".",
    "File name cannot be empty." : "Ní féidir leis an ainm comhaid a bheith folamh.",
    "\"/\" is not allowed inside a file name." : "Ní cheadaítear \"/\" taobh istigh d'ainm comhaid.",
    "\"{name}\" is not an allowed filetype" : "Ní cineál comhaid ceadaithe é \"{name}\".",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Tá stóráil {owner} lán, ní féidir comhaid a nuashonrú ná a shioncronú a thuilleadh!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Tá fillteán grúpa \"{mountPoint}\" lán, ní féidir comhaid a nuashonrú nó a shioncronú a thuilleadh!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Tá an stóras seachtrach \"{mountPoint}\" lán, ní féidir comhaid a nuashonrú ná a shioncronú a thuilleadh!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Tá do stóras lán, ní féidir comhaid a nuashonrú ná a shioncronú a thuilleadh!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Tá stóráil {owner} beagnach lán ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Tá fillteán grúpa \"{mountPoint}\" beagnach lán ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Tá an stóras seachtrach \"{mountPoint}\" beagnach lán ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Tá do stóras beagnach lán ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["meaitseálann \"{filter}\"","mheaitseáil \"{filter}\"","mheaitseáil \"{filter}\"","mheaitseáil \"{filter}\"","mheaitseáil \"{filter}\""],
    "Direct link was copied (only works for people who have access to this file/folder)" : "Cóipeáladh nasc díreach (oibreacha do dhaoine a bhfuil rochtain acu ar an gcomhad/fillteán seo amháin)",
    "Path" : "Cosán",
    "_%n byte_::_%n bytes_" : ["%n beart ","%n bearta ","%n bearta","%n bearta","%n bearta"],
    "Favored" : "B'fhearr leis",
    "Favor" : "Fabhar",
    "Copy direct link (only works for people who have access to this file/folder)" : "Cóipeáil nasc díreach (ní oibríonn ach do dhaoine a bhfuil rochtain acu ar an gcomhad/fillteán seo)",
    "Upload file" : "Uaslódáil comhad",
    "Not favored" : "Ní bail ar fónamh orthu",
    "An error occurred while trying to update the tags" : "Tharla earráid agus iarracht á déanamh na clibeanna a nuashonrú",
    "Upload (max. %s)" : "Uaslódáil (%s ar a mhéad)",
    "Submitting fields…" : "Réimsí á gcur isteach…",
    "Filter filenames…" : "Scag ainmneacha comhaid…",
    "Enable the grid view" : "Cumasaigh an radharc greille",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} fillteán","{folderCount} fillteáin","{folderCount} fillteáin","{folderCount} fillteáin","{folderCount} fillteáin"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} comhad","{fileCount} comhaid","{fileCount} comhaid","{fileCount} comhaid","{fileCount} comhaid"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 chomhad agus {folderCount} fillteán","1 chomhad agus {folderCount} fillteáin","1 chomhad agus {folderCount} fillteáin","1 chomhad agus {folderCount} fillteáin","1 chomhad agus {folderCount} fillteáin"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} comhad agus 1 fillteán","{fileCount} comhaid agus 1 fillteán","{fileCount} comhaid agus 1 fillteán","{fileCount} comhaid agus 1 fillteán","{fileCount} comhaid agus 1 fillteán"],
    "{fileCount} files and {folderCount} folders" : "comhaid {fileCount} agus fillteáin {folderCount}",
    "Personal Files" : "Comhaid Phearsanta",
    "Text file" : "Comhad téacs",
    "New text file.txt" : "Comhad téacs nua.txt",
    "%1$s (renamed)" : "%1$s (athainmnithe)",
    "renamed file" : "comhad athainmnithe",
    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Tar éis na hainmneacha comhad atá comhoiriúnach le Windows a chumasú, ní féidir comhaid atá ann cheana a mhodhnú a thuilleadh ach is féidir lena n-úinéir iad a athainmniú go hainmneacha nua bailí.",
    "Filter file names …" : "Scag ainmneacha na gcomhad…"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
